# frozen_string_literal: true

source "https://rubygems.org"

gem "rubocop", ">= 1.52.1", "< 2"
gem "rubocop-performance", "~> 1.14"
